* Create a table we'll import records into.

close databases all
create table Customers (Contact C(40), Address C(40), City C(20), State C(2), ;
	ZipCode C(10))

* Create the import object and specify the table to import from.

loImport = createobject('TestImport')
loImport.cTableName = 'Customers.dbf'

* Create the import file object.

loImport.oImportFile = newobject('SFImportFileDBF', 'SFImport.vcx')
loImport.oImportFile.cFileName = 'names.dbf'

* Load the import file definition.

loField = loImport.oImportFile.GetFileStructure()

* Load the mappings.

loMap = loImport.oMapping.Add('Contact')
loMap.uImportField = 'NAME'
loMap.cExpression  = 'proper(VALUE)'
loMap = loImport.oMapping.Add('Address')
loMap.uImportField = 'ADDRS1'
loMap.cExpression  = 'proper(VALUE)'
loMap = loImport.oMapping.Add('City')
loMap.uImportField = 'CITY'
loMap.cExpression  = 'proper(VALUE)'
loMap = loImport.oMapping.Add('State')
loMap.uImportField = 'SOURCE1'
loMap = loImport.oMapping.Add('ZipCode')
loMap.uImportField = 'POSTCODE'

* We only want customers in a certain range of zip codes.

loImport.cFilter = "between(Customers.ZipCode, '10000', '39999')"

* Do the import and show the results.

llSuccess = loImport.Import()
if llSuccess
	messagebox('Records processed: ' + ;
			transform(loImport.nRecordsProcessed) + chr(13) + ;
		'Records imported: ' + transform(loImport.nRecordsImported) + ;
			chr(13) + ;
		'Duplicate records: ' + transform(loImport.nDuplicateRecords) + ;
			chr(13) + ;
		'Filtered records: ' + transform(loImport.nFilteredRecords) + ;
			chr(13) + ;
		'Invalid records: ' + transform(loImport.nInvalidRecords), ;
		0, 'Import Results')
	select Customers
	browse
else
	messagebox(loImport.cErrorMessage)
endif llSuccess

define class TestImport as SFImport of SFImport.vcx
	function IsDuplicate(toRecord)
		local lnSelect, ;
			loRecord, ;
			llDuplicate
		lnSelect = select()
		select (This.cAlias)
		locate for Contact = toRecord.Contact and ZipCode = toRecord.ZipCode
		llDuplicate = found()
		select (lnSelect)
		return llDuplicate
	endfunc
enddefine
